@@ -9,7 +9,7 @@ from context import academic_us
 
 def test_filenotfound():
     try:
-        os.remove('./persontitles/data/academic_us.txt')
+        os.remove('./src/persontitles/data/academic_us.txt')
     except FileNotFoundError:
         pass
     ACADEMIC = academic_us.degrees_us()
